#
# spec file for package libmfx
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover 1
Name:           libmfx
%define lname   libmfx%{sover}
Version:        23.2.2
Release:        4.1
Summary:        The Intel Media SDK
License:        MIT
Group:          Development/Languages/C and C++
URL:            https://github.com/Intel-Media-SDK/MediaSDK
Source0:        %{url}/archive/intel-mediasdk-%{version}.tar.gz
Source1:        supplements.inc
Source2:        generate-supplements.sh
Patch0:         cmake-sle12.patch
Patch1:         gcc13-fix.patch
BuildRequires:  cmake
%if 0%{?suse_version} < 1500
BuildRequires:  gcc7-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(wayland-client)
ExclusiveArch:  x86_64

%description
The Intel Media SDK provides a plain C API to access hardware-accelerated
video decode, encode and filtering on Intel Gen graphics hardware
platforms. The implementation is written in C++11, with parts in C-for-Media
(CM).

%package -n %lname
Summary:        The Intel Media SDK
Group:          System/Libraries
%include %{S:1}

%description -n %lname
The Intel Media SDK provides a plain C API to access hardware-accelerated
video decode, encode and filtering on Intel Gen graphics hardware
platforms. The implementation is written in C++11, with parts in C-for-Media
(CM).

%package devel
Summary:        Development files Intel Media SDK
Group:          Development/Languages/C and C++
Requires:       %lname = %version

%description devel
This package contains the development headers and pkgconfig files for
the Intel Media SDK.

%package samples
Summary:        Examples for the Intel Media SDK
Group:          Development/Languages/C and C++

%description samples
This package contains example applications for the Intel Media SDK.

%prep
%autosetup -p1 -n MediaSDK-intel-mediasdk-%{version}

%build
mkdir -p build
pushd build
# libITT and cm compiler not available on openSUSE
cmake \
%if 0%{?suse_version} < 1500
-DCMAKE_CXX_COMPILER="%{_bindir}/g++-7" \
%endif
-DCMAKE_INSTALL_PREFIX="%{_prefix}" \
-DENABLE_X11_DRI3:BOOL=ON \
-DENABLE_WAYLAND:BOOL=ON \
-DENABLE_TEXTLOG:BOOL=ON \
-DENABLE_STAT:BOOL=ON \
-DBUILD_TESTS:BOOL=OFF \
-DBUILD_TOOLS:BOOL=OFF \
-DENABLE_ITT:BOOL=OFF \
-DCMAKE_SYSTEM_VERSION=6.14.0 \
-DBUILD_KERNELS:BOOL=OFF \
-DBUILD_TUTORIALS:BOOL=OFF \
-DBUILD_SAMPLES:BOOL=OFF \
..
make %{?_smp_mflags}
popd

%install
pushd build
%make_install
popd
#mkdir -p %{buildroot}/%{_libdir}/mfx/samples
#mv %{buildroot}/%{_datadir}/mfx/samples/* \
#   %{buildroot}/%{_libdir}/mfx/samples
#rmdir %{buildroot}/%{_datadir}/mfx/samples

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files
%doc CHANGELOG.md CODEOWNERS README.rst
%exclude %{_bindir}/asg-hevc
%exclude %{_bindir}/hevc_fei_extractor
%exclude %{_bindir}/mfx-tracer-config

%files -n %lname
%license LICENSE
%exclude %{_libdir}/libmfx.so.%{sover}
%exclude %{_libdir}/libmfx.so.%{sover}.*
%{_libdir}/libmfxhw64.so.%{sover}
%{_libdir}/libmfxhw64.so.%{sover}.*
%exclude %{_libdir}/libmfx-tracer.so.%{sover}
%exclude %{_libdir}/libmfx-tracer.so.%{sover}.*
%dir %{_libdir}/mfx
%{_libdir}/mfx/libmfx_*_hw64.so
%dir %{_datadir}/mfx
%{_datadir}/mfx/plugins.cfg

#%files samples
%exclude %{_libdir}/mfx/samples/

#%files devel
%exclude %{_includedir}/mfx/
%exclude %{_libdir}/libmfx.so
%exclude %{_libdir}/libmfxhw64.so
%exclude %{_libdir}/libmfx-tracer.so
%exclude %{_libdir}/pkgconfig/*.pc

%changelog
* Fri May  9 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Stop storing build machine kernel version (boo#1101107)
* Mon Feb  5 2024 Stefan Dirsch <sndirsch@suse.com>
- disabled compiling samples, tools and tutorials, which are no
  longer packaged anyway
* Sat Feb  3 2024 Stefan Dirsch <sndirsch@suse.com>
- only package hardware specific ibmfxhw64 (+ libmfx_<codec>_hw64
  plugins) loaded during runtime by libvpl (boo#1219494)
- drop -devel and -samples subpackages
* Sat Feb  3 2024 Stefan Dirsch <sndirsch@suse.com>
- added hardware supplements, so it will be installed on GPUs which
  are not supported by libmfx-gen (boo#1219494)
* Mon Dec  4 2023 Stefan Dirsch <sndirsch@suse.com>
- This includes latest version of one of the components needed for
  Video (processing) hardware support on Intel GPUs (bsc#1217770)
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 23.2.2:
  * [Encode] Fix JPEG payload insertion on Linux
  * Update checking of bitsream left size (#3033)
  * [Decode] Fix memory out-of-bounds issue for VP9
  * [Decode] Fix memory out-of-bounds issue for VP8
  * [Decode]Remove AVC level 6.0 check
  * [Decode]Fix hevc decode issue
  * hevce: use Low Power mode for RGB encoding by default
* Mon Mar  6 2023 Martin Liška <mliska@suse.cz>
- Add upstream gcc13-fix.patch patch.
* Sun Jan  8 2023 Dirk Müller <dmueller@suse.com>
- update to 22.6.5:
  * Add security reporting information
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 22.6.4:
  * Fix VC1 Decode assertion failure when frame type is NONE_PICTURE
* Mon Nov  7 2022 Stefan Dirsch <sndirsch@suse.com>
- needed for jira#PED-1174 (Video decoding/encoding support
  (VA-API, ...) for Intel GPUs is outside of Mesa)
* Thu Nov  3 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 22.6.1
  * latest bugfix release
* Mon Jul 11 2022 Stefan Dirsch <sndirsch@suse.com>
- No code changes
- Update to version 22.4.4 was part of Intel oneVPL GPU Runtime
  2022Q2 Release 22.4.4
* Fri Jul  8 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 22.4.4
  * Decode
    + Fix VC1 Decode assertion failure when frame type is NONE_PICTURE
  * Software requirements
    + Libdrm 2.4.84 or later
    + Kernel 4.14 or later (5.4 recommended, consult kernel support matrix
    wiki page for details)
  * Known issues
    + Kernel 5.0 have known issue with endurance on Skylake see
    https://bugs.freedesktop.org/show_bug.cgi?id=110285 for details.
  * Windows support
    + Samples and dispatcher API 1.35 supported by Windows Intel(r) graphics
    driver since 27.20.100.8935 version.
  * Limited support on certain platforms:
    + MPEG-2 encode is not supported on Apollo Lake
    + H.264 Flexible Encode Infrastructure only supported on Broadwell and
    Skylake
    + Multi Frame Encode (MFE), HEVC Flexible Encode Infrastructure only
    supported on Skylake
    + VP9 decoder is supported starting from Kabylake platform
    + VP9 encoder is supported starting from Icelake platform
    + SW fallback is unsupported for all components but MJPEG
    + Keem Bay requires a VPU runtime library
    + The following features are supported by Keem Bay runtime and are not
    supported by Gen graphics runtime:
  * mfxExtInsertHeaders
  * mfxExtEncoderIPCMArea
* Mon Nov 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 21.3.5:
  * single change: Updates release notes for 21.3.4 release
  * New features:
    + VP9 Encode: Added WebRTC mode.
    + Samples:
    . Added "VuiTC" option to set VUI TransferCharacteristics in
    sample_multi_transcode.
    . Added the verification of input params before used in Init
    for sample_encode
    + Misc:
    . Added support of DRM_FORMAT_NV12 for console mode
    rendering.
    . Added runtimes support matrix for Media SDK and oneVPL GPU
    Runtime.
    + Software requirements:
    . Libdrm 2.4.84 or later
    . Kernel 4.14 or later (5.4 recommended, consult kernel
    support matrix wiki page for details)
    + Known issues: Kernel 5.0 have known issue with endurance on
    Skylake see
    https://bugs.freedesktop.org/show_bug.cgi?id=110285 for
    details.
  * Limited support on certain platforms:
    + MPEG-2 encode is not supported on Apollo Lake
    + H.264 Flexible Encode Infrastructure only supported on
    Broadwell and Skylake
    + Multi Frame Encode (MFE), HEVC Flexible Encode Infrastructure
    only supported on Skylake
    + VP9 decoder is supported starting from Kabylake platform
    + VP9 encoder is supported starting from Icelake platform
    + SW fallback is unsupported for all components but MJPEG
    + Keem Bay requires a VPU runtime library
    + The following features are supported by Keem Bay runtime and
    are not supported by Gen graphics runtime:
    . mfxExtInsertHeaders
    . mfxExtEncoderIPCMArea
* Mon Oct  4 2021 Stefan Dirsch <sndirsch@suse.com>
- fixed JIRA number in previous changelog
* Wed Sep 29 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to 21.3.4
  * Fixed VPL run-time loading by MediaSDK dispatcher
    VPL doesn't provide libmfx-gen.so.1
    In VPL Gen run-time we have libmfx-gen.so.1.2 as SONAME and
    use libmfx-gen.so.1.2.x as a full name.
  * [VPP] Fix increasing num of input channels doesn't work
  * maximum and minmum qp setting for HEVC encoder.
  * Removed multiple calls vaGetConfigAttributes (github
    issue#2417)
  * [Jpeg]modify color range on Linux
  * [Jpegd] Enable HW to decode JPEG RGB444 on Linux
* Mon Sep 27 2021 Stefan Dirsch <sndirsch@suse.com>
- covers jira#SLE/SLE-19361
* Wed Sep 22 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to 21.3.3
  * latest version
- refreshed cmake-sle12.patch
- supersedes u_gcc11.patch
* Wed Feb 10 2021 Stefan Dirsch <sndirsch@suse.com>
- u_gcc11.patch
  * fixes build against gcc11 (boo#1181871)
* Sat Oct 10 2020 Dirk Mueller <dmueller@suse.com>
- update to 20.3.0:
  * Added Keem Bay platform support
  * Added AV1 decode support
  * Added implicit Motion-Compensated Temporal Filter (MCTF) to improve coding quality on certain scenarios
  * Improved CodecLevel initialization from rate control parameters
  * Added support of 4k streams with look-ahead bitrate control mode
  * Enabled QPOffset by default
  * Improved efficiency of FPQ
  * Enabled QP modulation (Icelake+)
  * Added 16k support
  * Added A2RGB10 input in case of passthru copy
  * Added -dec::sys flag for setting of the output memory to system type in sample_multi_transcode
  * Added p016/y216 support in sample_encode
  * Added i420/nv12 support in sample_multi_transcode
  * Fixed chroma size for Y210/Y216 formats in sample_deocde
  * Added handle for iterpolation methods for resize in sample_vpp
  * Added support for discrete Intel Xe graphics codenamed DG1 and SG1
  * Added support for Rocketlake platform
  * Actualized Elkhartlake device id support list
* Mon Aug 31 2020 Stefan Dirsch <sndirsch@suse.com>
- version 20.2.1 needed for jira#SLE/SLE-12712
* Thu Aug 27 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 20.2.1
  * Samples: Fixed #2190. rotate_opencl plugin switched to recent
    version of OpenCL C++ headers, validated with OpenCL-CLHPP
    v2.0.12 and OpenCL-Headers v2020.06.16 / Intel® SDK for OpenCL™
    Applications for Windows* 2020.2.487.
* Thu Aug 27 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 20.2.0
  * bugfixes and improvements
  * includes: Build system does not enforce specific instruction
    set (issue#2047, boo#1167346)
- supersedes u_buildfix-for-gcc10.patch
* Mon Aug  3 2020 Fabian Vogt <fvogt@suse.com>
- Move samples into a new subpackage
- The library does not depend on the tools, drop Requires
- Apply patch unconditionally, use %%autosetup
- Move LICENSE to library package
- Make the sover part of %%files
- Don't bother building tests, they're not run anyway
* Mon Mar 16 2020 Stefan Dirsch <sndirsch@suse.com>
- u_buildfix-for-gcc10.patch
  * fixes build against gcc10 (boo#1166609)
* Tue Mar  3 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 19.4.0:
  * bugfixes and improvements
* Thu Nov  7 2019 Stefan Dirsch <sndirsch@suse.com>
- This release fullfills requirements for jsc#SLE-8841
* Tue Sep  3 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to release 19.2.1
  * bugfixes and improvements
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- More consistent macro usage throughout.
- Grammar fixes to description.
* Tue Jun 11 2019 Stefan Dirsch <sndirsch@suse.com>
- added more features to build
  * X11_DRI3
  * WAYLAND
  * TEXTLOG
  * STAT
  * TESTS
  * TOOLS
- ITT and KERNELS features remain disabled for now since libITT
  and cm compiler is not available on (open)SUSE right now
- gcc7 needed for building tests on sle12-sp5
- moved documentation and binaries to main package; let require
  the library subpackage the main package
* Fri Jun  7 2019 Stefan Dirsch <sndirsch@suse.com>
- cmake-sle12.patch
  * needed for cmake 3.5.2 on sle12-sp5
* Thu Jun  6 2019 Stefan Dirsch <sndirsch@suse.com>
- created package for Intel Media SDK (jira #SLE-4968, bsc#1137651)
